cheesecake.codeparser

Package cheesecake :: Module codeparser |
[show private | hide private]
[frames | no frames]

## Module cheesecake.codeparser

Classes
`CodeParser` | Information about the structure of a Python module.

Function Summary
| ``compile_regex`(pattern, user_map)` Compile a regex pattern using default or user mapping.
| `inline_markup(start, end, mapping)`
| `line_markup(start, end)`
| ``use_format`(text, format)` Return True if text includes given documentation format and False otherwise.

Variable Summary
`dict` | `supported_formats` = `{'epytext': [<_sre.SRE_Pattern objec...`

Function Details

### compile_regex(pattern, user_map=None) Compile a regex pattern using default or user mapping.

### use_format(text, format) Return True if text includes given documentation format and False otherwise. See supported_formats for list of known formats.

Variable Details

    ### supported_formats Type: `dict` Value:
        {'epytext': [<_sre.SRE_Pattern object at 0xb7aed408>,
                     <_sre.SRE_Pattern object at 0x829dc10>,
                     <_sre.SRE_Pattern object at 0x829cfa0>,
                     <_sre.SRE_Pattern object at 0x829e3b0>],
         'javadoc': [<_sre.SRE_Pattern object at 0xb7c12de0>,
                     <_sre.SRE_Pattern object at 0x829e738>,
                     <_sre.SRE_Pattern object at 0x8297998>],
         'reST': [<_sre.SRE_Pattern object at 0x829bc98>,
        ...

Generated by Epydoc 2.1 on Fri Feb 9 02:15:12 2007 | http://epydoc.sf.net